@@ -38,6 +38,29 @@ print.svyglm.nb <- function(x, se = c("robust", "model"), digits = 4, ...) {
 
 
 
+#' @importFrom stats coef vcov pnorm
+#' @importFrom dplyr case_when
+#' @export
+print.svyglm.zip <- function(x, se = c("robust", "model"), digits = 4, ...) {
+  se <- match.arg(se)
+  sm <- tidy_svyglm.zip(x, digits, v_se = se)[-1, ]
+
+  pan <- dplyr::case_when(
+    sm$p.value < 0.001 ~ "<0.001 ***",
+    sm$p.value < 0.01 ~ sprintf("%.*f ** ", digits, sm$p.value),
+    sm$p.value < 0.05 ~ sprintf("%.*f *  ", digits, sm$p.value),
+    sm$p.value < 0.1 ~ sprintf("%.*f .  ", digits, sm$p.value),
+    TRUE ~  sprintf("%.*f    ", digits, sm$p.value)
+  )
+
+  sm$p.value <- pan
+  print(sm, ...)
+
+  message(sprintf("\nShowing %s standard errors on link-scale (untransformed).", se))
+}
+
+
+
 #' @importFrom stats qnorm coef pnorm vcov
 tidy_svyglm.nb <- function(x, digits = 4, v_se = c("robust", "model")) {
   v_se <- match.arg(v_se)
@@ -62,6 +85,29 @@ tidy_svyglm.nb <- function(x, digits = 4, v_se = c("robust", "model")) {
 
 
 
+#' @importFrom stats qnorm coef pnorm vcov
+tidy_svyglm.zip <- function(x, digits = 4, v_se = c("robust", "model")) {
+  v_se <- match.arg(v_se)
+
+  if (!isNamespaceLoaded("survey"))
+    requireNamespace("survey", quietly = TRUE)
+
+  # keep original value, not rounded
+  est <- stats::coef(x)
+  se <- sqrt(diag(stats::vcov(x, stderr = v_se)))
+
+  data_frame(
+    term = substring(names(stats::coef(x)), 5),
+    estimate = round(est, digits),
+    std.error = round(se, digits),
+    conf.low = round(exp(est - stats::qnorm(.975) * se), digits),
+    conf.high = round(exp(est + stats::qnorm(.975) * se), digits),
+    p.value = round(2 * stats::pnorm(abs(est / se), lower.tail = FALSE), digits)
+  )
+}
+
+
+
 #' @importFrom dplyr select
 #' @export
 model.frame.svyglm.nb <- function(formula, ...) {
@@ -71,6 +117,15 @@ model.frame.svyglm.nb <- function(formula, ...) {
 
 
 
+#' @importFrom dplyr select
+#' @export
+model.frame.svyglm.zip <- function(formula, ...) {
+  pred <- attr(formula, "zip.terms", exact = T)
+  dplyr::select(formula$design$variables, string_one_of(pattern = pred, x = colnames(formula$design$variables)))
+}
+
+
+
 #' @export
 family.svyglm.nb <- function(object, ...) {
   attr(object, "family", exact = TRUE)
@@ -85,6 +140,13 @@ formula.svyglm.nb <- function(x, ...) {
 
 
 
+#' @export
+formula.svyglm.zip <- function(x, ...) {
+  attr(x, "zip.formula", exact = TRUE)
+}
+
+
+
 #' @importFrom MASS glm.nb
 #' @importFrom stats coef setNames predict.glm
 #' @export
@@ -179,443 +241,27 @@ deviance.svyglm.nb <- function(object, ...) {
 
 
 #' @importFrom insight print_color
-#' @importFrom rlang .data
-#' @importFrom dplyr filter slice select
-#' @importFrom sjmisc var_rename trim
 #' @export
 print.tidy_stan <- function(x, ...) {
-  insight::print_color("\n# Summary Statistics of Stan-Model\n\n", "blue")
-
-  # check if data has certain terms, so we know if we print
-  # zero inflated or multivariate response models
-
-  zi <- string_starts_with(pattern = "b_zi_", x = x$term)
-  resp.cor <- string_starts_with(pattern = "rescor__", x = x$term)
-  ran.eff <- obj_has_name(x, "random.effect")
-  multi.resp <- obj_has_name(x, "response")
-  cumulative <- obj_has_name(x, "response.level")
-
-  if (cumulative) x <- sjmisc::var_rename(x, response.level = "response")
-
-  x$term <- gsub("^b_", "", x$term)
-  x$term <- gsub(pattern = "^bsp_mo", replacement = "", x = x$term)
-  simplex <- string_starts_with(pattern = "simo_mo", x = x$term)
-  x$term <- gsub(
-    pattern = "^simo_mo(.*)(\\.)(.*)(\\.)",
-    replacement = "\\1 \\[\\3\\]",
-    x = x$term
-  )
-  x$simplex <- ""
-  if (!sjmisc::is_empty(simplex))
-    x$simplex[simplex] <- "simplex"
-
-  if (is.null(attr(x, "trans"))) {
-    x <- get_hdi_data(x, digits = as.numeric(attr(x, "digits")))
-  } else {
-    x <- get_hdi_data(x, digits = as.numeric(attr(x, "digits")), ci_pattern = "ci.", ci_name = "CI")
-  }
-
-  # print zero-inflated models ----
-
-  if (!sjmisc::is_empty(zi)) {
-
-    # if we have random effects, make sure that any random effects
-    # from zero-inlfated model are correctly handled here
-
-    if (ran.eff) {
-      zi <- union(zi, string_contains(pattern = "__zi", x = x$term))
-    }
-
-    x.zi <- dplyr::slice(x, !! zi)
-    x <- dplyr::slice(x, -!! zi)
-
-    x.zi$term <- gsub("(^b_zi_)", "", x.zi$term)
-    x.zi$term <- gsub("(^zi_)", "", x.zi$term)
-
-    x$term <- clean_term_name(x$term)
-    x.zi$term <- clean_term_name(x.zi$term)
-
-    if (ran.eff) {
-      print_stan_ranef(x, zeroinf = TRUE)
-    } else {
-      simplex <- which(x$simplex == "simplex")
-
-      if (!sjmisc::is_empty(simplex)) {
-        x.sp <- dplyr::slice(x, !! simplex)
-        x <- dplyr::slice(x, -!! simplex)
-      } else
-        x.sp <- NULL
-
-      insight::print_color("## Conditional Model:\n\n", "blue")
-
-      x <- trim_hdi(x)
-      colnames(x)[1] <- ""
-
-      x %>%
-        dplyr::select(-.data$simplex) %>%
-        as.data.frame() %>%
-        print(..., row.names = FALSE)
-      cat("\n")
-
-      if (!is.null(x.sp))
-        print_stan_simplex(x.sp)
-    }
-
-
-    if (ran.eff) {
-      print_stan_zeroinf_ranef(x.zi)
-    } else {
-      simplex <- which(x$simplex == "simplex")
-
-      if (!sjmisc::is_empty(simplex)) {
-        x.sp <- dplyr::slice(x.zi, !! simplex)
-        x.zi <- dplyr::slice(x.zi, -!! simplex)
-      } else
-        x.sp <- NULL
-
-      insight::print_color("## Zero-Inflated Model:\n\n", "blue")
-
-      x.zi <- trim_hdi(x.zi)
-      colnames(x.zi)[1] <- ""
-
-      x.zi %>%
-        dplyr::select(-.data$simplex) %>%
-        as.data.frame() %>%
-        print(..., row.names = FALSE)
-      cat("\n")
-
-      if (!is.null(x.sp))
-        print_stan_simplex(x.sp)
-    }
-
-
-    # print multivariate response models ----
-
-  } else if (!sjmisc::is_empty(resp.cor) || multi.resp || cumulative) {
-
-    # get the residual correlation information from data
-    x.cor <- dplyr::slice(x, !! resp.cor)
-
-    # if we have any information, remove it from remaining summary
-    if (!sjmisc::is_empty(resp.cor))
-      x <- dplyr::slice(x, -!! resp.cor)
-
-    # first, print summary for each response model
-    responses <- unique(x$response)
-    resp.string <- ""
-    if (cumulative) resp.string <- "-level"
-
-    for (resp in responses) {
-
-      if (ran.eff) {
-        print_stan_mv_re(x, resp)
-      } else {
-
-        insight::print_color(sprintf("## Response%s:", resp.string), "blue")
-        insight::print_color(sprintf(" %s\n\n", resp), "red")
-
-        xr <- x %>%
-          dplyr::filter(.data$response == !! resp) %>%
-          dplyr::select(-1, -.data$simplex) %>%
-          dplyr::mutate(term = clean_term_name(.data$term)) %>%
-          trim_hdi() %>%
-          as.data.frame()
-
-        colnames(xr)[1] <- ""
-        print(xr, ..., row.names = FALSE)
-
-        cat("\n")
-      }
-    }
-
-    # finally, if we had information on residual correlation,
-    # print this as well. if "set_rescor"(FALSE)", this part
-    # would be missing
-
-    if (nrow(x.cor) > 0) {
-      x.cor$term <- clean_term_name(x.cor$term)
-      x.cor$term <- gsub("rescor__", "", x = x.cor$term, fixed = TRUE)
-      x.cor$term <- gsub("__", "-", x = x.cor$term, fixed = TRUE)
-
-      insight::print_color("## Residual Correlations\n\n", "cyan")
-
-      x.cor <- x.cor %>%
-        dplyr::select(-1, -.data$simplex) %>%
-        sjmisc::var_rename(term = "correlation") %>%
-        trim_hdi() %>%
-        as.data.frame()
-
-      colnames(x.cor)[1] <- ""
-      print(x.cor, ..., row.names = FALSE)
-    }
-  } else if (ran.eff) {
-
-    # print random effects models ----
-
-    print_stan_ranef(x)
-
-  } else {
-
-    simplex <- which(x$simplex == "simplex")
-
-    if (!sjmisc::is_empty(simplex)) {
-      x.sp <- dplyr::slice(x, !! simplex)
-      x <- dplyr::slice(x, -!! simplex)
-    } else
-      x.sp <- NULL
-
-    colnames(x)[1] <- ""
-    x %>%
-      dplyr::select(-.data$simplex) %>%
-      as.data.frame() %>%
-      print(..., row.names = FALSE)
-
-    if (!is.null(x.sp)) {
-      cat("\n")
-      print_stan_simplex(x.sp, ...)
-    }
-  }
-}
-
-
-
-print_stan_simplex <- function(x, ...) {
-  insight::print_color("## Simplex Parameters:\n\n", "blue")
-
-  x <- trim_hdi(x)
-
-  if (colnames(x)[1] != "term")
-    x <- dplyr::select(x, -1)
-
-  colnames(x)[1] <- ""
-
-  x %>%
-    dplyr::select(-.data$simplex) %>%
-    as.data.frame() %>%
-    print(..., row.names = FALSE)
-  cat("\n")
-}
-
-
-#' @importFrom sjmisc is_empty
-#' @importFrom dplyr slice select filter mutate
-print_stan_ranef <- function(x, zeroinf = FALSE) {
-  # find fixed effects - if type = "all"
-  fe <- which(x$random.effect == "")
-
-  if (!sjmisc::is_empty(fe)) {
-
-    if (!zeroinf) {
-      insight::print_color("## Fixed effects:\n\n", "blue")
-    } else {
-      insight::print_color("## Conditional Model: Fixed effects\n\n", "blue")
-    }
-
-    # if we have fixed and random effects, get information for
-    # fixed effects, and then remove these summary lines from
-    # the data frame, so only random effects remain for later
-
-    x.fe <- dplyr::slice(x, !! fe)
-    x <- dplyr::slice(x, -!! fe)
-
-    simplex <- which(x.fe$simplex == "simplex")
-
-    if (!sjmisc::is_empty(simplex)) {
-      x.sp <- dplyr::slice(x.fe, !! simplex)
-      x.fe <- dplyr::slice(x.fe, -!! simplex)
-    } else
-      x.sp <- NULL
-
-    x.fe$term <- clean_term_name(x.fe$term)
-    x.fe <- trim_hdi(x.fe)
-
-    colnames(x.fe)[2] <- ""
-
-    x.fe %>%
-      dplyr::select(-1, -.data$simplex) %>%
-      as.data.frame() %>%
-      print(row.names = FALSE)
-
-    cat("\n")
-
-    if (!is.null(x.sp))
-      print_stan_simplex(x.sp)
-  }
-
-  # iterate all random effects
-  re <- unique(x$random.effect)
-
-  # remove random effects from zero inflated model
-  re.zi <- string_contains(pattern = "__zi", x = re)
-  if (!sjmisc::is_empty(re.zi)) re <- re[-re.zi]
-
-  for (r in re) {
-
-    if (!zeroinf) {
-      insight::print_color("## Random effect ", "blue")
-      insight::print_color(sprintf("%s\n\n", r), "red")
-    } else {
-      insight::print_color("## Conditional Model: Random effect ", "blue")
-      insight::print_color(sprintf("%s\n\n", r), "red")
-    }
-
-    xr <- x %>%
-      dplyr::filter(.data$random.effect == !! r) %>%
-      dplyr::select(-1, -.data$simplex) %>%
-      dplyr::mutate(term = clean_term_name(.data$term)) %>%
-      trim_hdi() %>%
-      as.data.frame()
-
-    colnames(xr)[1] <- ""
-    print(xr, row.names = FALSE)
-
-    cat("\n")
-  }
-}
-
-
-#' @importFrom sjmisc is_empty
-trim_hdi <- function(x) {
-  cn <- colnames(x)
-  hdi.cols <- string_starts_with(pattern = "HDI", x = cn)
-
-  if (!sjmisc::is_empty(hdi.cols)) {
-    x <- x %>%
-      purrr::map_at(hdi.cols, function(i) {
-        spaces <- grep(pattern = "[ ", i, fixed = TRUE)
-        if (length(spaces) == length(i))
-          i <- gsub("[ ", "[", i, fixed = TRUE)
-
-        spaces <- grep(pattern = " ]", i, fixed = TRUE)
-        if (length(spaces) == length(i))
-          i <- gsub(" ]", "]", i, fixed = TRUE)
-
-        i
-      }) %>%
-      as.data.frame()
-
-    colnames(x) <- cn
-  }
-  x
-}
-
-
-#' @importFrom sjmisc is_empty
-#' @importFrom dplyr slice select filter mutate
-print_stan_mv_re <- function(x, resp) {
-  # find fixed effects - is type = "all"
-  fe <- which(x$random.effect == "")
-
-  if (!sjmisc::is_empty(fe)) {
-
-    insight::print_color("## Fixed effects for response: ", "blue")
-    insight::print_color(sprintf("%s\n\n", resp), "red")
-
-    x.fe <- dplyr::slice(x, !! fe)
-    x <- dplyr::slice(x, -!! fe)
-
-    xr <- x.fe %>%
-      dplyr::filter(.data$response == !! resp) %>%
-      dplyr::select(-1:-2, -.data$simplex) %>%
-      dplyr::mutate(term = clean_term_name(.data$term)) %>%
-      trim_hdi() %>%
-      as.data.frame()
-
-    colnames(xr)[1] <- ""
-    print(xr, row.names = FALSE)
-
-    cat("\n")
-  }
-
-  # iterate all random effects
-  re <- unique(x$random.effect)
-
-  for (r in re) {
-
-    find.re <- which(x$random.effect == r & x$response == resp)
-
-    if (!sjmisc::is_empty(find.re)) {
-      insight::print_color("## Random effect ", "blue")
-      insight::print_color(sprintf("%s", resp), "red")
-      insight::print_color(" for response ", "blue")
-      insight::print_color(sprintf("%s\n\n", resp), "red")
-
-      xr <- x %>%
-        dplyr::filter(.data$random.effect == !! r, .data$response == !! resp) %>%
-        dplyr::select(-1:-2) %>%
-        dplyr::mutate(term = clean_term_name(.data$term)) %>%
-        trim_hdi() %>%
-        as.data.frame()
-
-      colnames(xr)[1] <- ""
-      print(xr, row.names = FALSE)
-
-      cat("\n")
-    }
-  }
-}
-
-
-#' @importFrom sjmisc is_empty
-#' @importFrom dplyr slice select filter mutate
-print_stan_zeroinf_ranef <- function(x) {
-  # find fixed effects - is type = "all"
-  fe <- which(x$random.effect == "")
-
-  if (!sjmisc::is_empty(fe)) {
-
-    insight::print_color("## Zero-Inflated Model: Fixed effects\n\n", "blue")
-
-    # if we have fixed and random effects, get information for
-    # fixed effects, and then remove these summary lines from
-    # the data frame, so only random effects remain for later
-
-    x.fe <- dplyr::slice(x, !! fe)
-    x <- dplyr::slice(x, -!! fe)
-    x.fe$term <- clean_term_name(x.fe$term)
-    x.fe <- trim_hdi(x.fe)
-
-    colnames(x.fe)[2] <- ""
-
-    x.fe %>%
-      dplyr::select(-1, -.data$simplex) %>%
-      as.data.frame() %>%
-      print(row.names = FALSE)
-
-    cat("\n")
-  }
-
-  # iterate all random effects
-  re <- unique(x$random.effect)
-
-  # remove random effects from zero inflated model
-  re.zi <- string_contains(pattern = "__zi", x = re)
-
-  if (!sjmisc::is_empty(re.zi)) {
-
-    re <- re[re.zi]
-
-    x$random.effect <- gsub("__zi", "", x$random.effect, fixed = TRUE)
-    x$term <- gsub("__zi", "", x$term, fixed = TRUE)
-    re <- gsub("__zi", "", re, fixed = TRUE)
-
-    for (r in re) {
-
-      insight::print_color("## Zero-Inflated Model: Random effect ", "blue")
-      insight::print_color(sprintf("%s\n\n", r), "red")
-
-      xr <- x %>%
-        dplyr::filter(.data$random.effect == !! r) %>%
-        dplyr::select(-1, -.data$simplex) %>%
-        dplyr::mutate(term = clean_term_name(.data$term)) %>%
-        trim_hdi() %>%
-        as.data.frame()
-
-      colnames(xr)[1] <- ""
-      print(xr, row.names = FALSE)
-
-      cat("\n")
-    }
+  insight::print_color("\nSummary Statistics of Stan-Model\n\n", "blue")
+  digits <- attr(x, "digits")
+
+  for (i in x) {
+    insight::print_color(paste0("# ", attr(i, "main_title")), "blue")
+    cat(" ")
+    insight::print_color(attr(i, "sub_title"), "red")
+    cat("\n\n")
+    rem <- which(colnames(i) %in% c("Parameter", "Group", "Response", "Function"))
+    i <- i[, -rem]
+    colnames(i)[1] <- "Parameter"
+    i$ESS <- as.character(i$ESS)
+    i$pd <- sprintf("%.1f%%", 100 * i$pd)
+    i[] <- lapply(i, function(.j) {
+      if (is.numeric(.j)) .j <- sprintf("%.*f", digits, .j)
+      .j
+    })
+    print.data.frame(i, quote = FALSE, row.names = FALSE)
+    cat("\n\n")
   }
 }
 
@@ -656,26 +302,6 @@ print.sj_resample <- function(x, ...) {
 
 
 
-#' @export
-print.sj_se_icc <- function(x, ...) {
-  if (x$adjusted)
-    cat("Standard Error of adjusted ICC\n")
-  else
-    cat("Standard Error of ICC\n")
-
-  cat(sprintf("      Model: %s\n", x$result$model[[1]]))
-
-  for (i in 1:nrow(x$result)) {
-    cat(sprintf("        ICC: %.4f\n", x$result$icc[i]))
-    cat(sprintf("  std. err.: %.4f\n", x$result$std.err[i]))
-    cat(sprintf("    p-value: %.4f\n", x$result$p.value[i]))
-
-    if (i < nrow(x$result)) cat("\n")
-  }
-}
-
-
-
 #' @importFrom tidyr gather
 #' @importFrom rlang .data
 #' @export
@@ -839,19 +465,6 @@ print.sj_xtab_stat <- function(x, ...) {
 
 
 
-#' @export
-print.sj_pred_accuracy <- function(x, ...) {
-  # headline
-  insight::print_color("\n# Accuracy of Model Predictions\n\n", "blue")
-
-  # statistics
-  cat(sprintf("Accuracy: %.2f%%\n", 100 * x$accuracy))
-  cat(sprintf("      SE: %.2f%%-points\n", 100 * x$std.error))
-  cat(sprintf("  Method: %s", x$stat))
-}
-
-
-
 #' @export
 print.sj_grpmean <- function(x, ...) {
   cat("\n")
@@ -948,57 +561,6 @@ print.sj_mediation <- function(x, digits = 2, ...) {
 }
 
 
-#' @importFrom purrr map_at map_df
-#' @importFrom dplyr bind_cols select
-get_hdi_data <- function(x, digits, ci_pattern = "hdi.", ci_name = "HDI") {
-  cn <- colnames(x)
-  prob <- attr(x, "prob", exact = TRUE)
-
-  hdi.cols <- string_starts_with(pattern = ci_pattern, x = cn)
-
-  # convert all to character, with fixed fractional part
-  x <- x %>%
-    purrr::map_at(hdi.cols, ~ sprintf("%.*f", digits, .x)) %>%
-    as.data.frame(stringsAsFactors = FALSE)
-
-  # left-justify term column
-  x$term <- format(x$term, justify = "left")
-
-  ci_cols <- hdi.cols[seq(1, length(hdi.cols), by = 2)]
-  ci_pos <- as.vector(regexpr("_", cn))
-
-  dummy <- purrr::map(ci_cols, function(i) {
-    # get length of longest value, for proper formatting
-    ml1 <- max(nchar(x[[i]]))
-    ml2 <- max(nchar(x[[i + 1]]))
-
-    tmp <- data_frame(hdi = sprintf("[%*s %*s]", ml1, x[[i]], ml2, x[[i + 1]]))
-
-    if (ci_pos[i] < 0) {
-      if (!is.null(prob))
-        interv <- 100 * prob[1]
-      else
-        interv <- 90
-    } else
-      interv <- as.numeric(substr(cn[i], ci_pos[i] + 1, nchar(cn[i])))
-
-    colnames(tmp) <- sprintf("%s(%.9g%%)", ci_name, interv)
-    tmp
-  }) %>%
-    dplyr::bind_cols()
-
-  # colnames(dummy) <- new_cn
-
-  x <- dplyr::select(x, !! -hdi.cols)
-  dat <- dplyr::bind_cols(x[, 1:(hdi.cols[1] - 1), drop = FALSE], dummy)
-
-  if (ncol(x) >= hdi.cols[1])
-    dat <- dplyr::bind_cols(dat, x[, hdi.cols[1]:ncol(x), drop = FALSE])
-
-  dat
-}
-
-
 #' @export
 print.sj_pval <- function(x, digits = 3, summary = FALSE, ...) {
 
@@ -1105,7 +667,7 @@ print.sj_ttest <- function(x, ...) {
     cat(sprintf("  %s: %.3f\n", format(l2, width = slen), x$estimate[2]))
     cat(sprintf("  %s: %.3f [%.3f  %.3f]\n", format(l3, width = slen), x$estimate[1] - x$estimate[2], x$ci[1], x$ci[2]))
   } else {
-    cat(sprintf("  mean of %s: %.3f [%.3f  %.3f]\n", xn, x$estimate[1], x$ci[1], x$ci[2]))
+    cat(sprintf("  mean of %s: %.3f [%.3f, %.3f]\n", xn, x$estimate[1], x$ci[1], x$ci[2]))
   }
 
   cat("\n")
