@@ -14,6 +14,9 @@ options(width = 800)
 if (!requireNamespace("mediation", quietly = TRUE)) {
   warning("Package 'mediation' required for this vignette.", call. = FALSE)
 }
+if (!requireNamespace("httr", quietly = TRUE)) {
+  warning("Package 'mediation' required for this vignette.", call. = FALSE)
+}
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjstats)
@@ -43,7 +46,12 @@ tidy_stan(m3, typical = "mean")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # printing fixed and random effects of multilevel model
-tidy_stan(m3, type = "all")
+tidy_stan(m3, effects = "all")
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# printing fixed and random effects of multilevel model, 
+# only zero-inflated model part.
+tidy_stan(m3, effects = "all", component = "zero_inflated")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # two different HDI for multivariate response model
