@@ -19,22 +19,22 @@ m2 <- lmer(Reaction ~ Days + (1 | mygrp) + (1 | Subject), sleepstudy)
 # Design effect for two-level model with 30 observations per
 # cluster group (level-2 unit) and an assumed intraclass
 # correlation coefficient of 0.05.
-deff(n = 30)
+design_effect(n = 30)
 
 # Design effect for two-level model with 24 observation per cluster
 # group and an assumed intraclass correlation coefficient of 0.2.
-deff(n = 24, icc = 0.2)
+design_effect(n = 24, icc = 0.2)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # Sample size for multilevel model with 30 cluster groups and a small to
 # medium effect size (Cohen's d) of 0.3. 27 subjects per cluster and
 # hence a total sample size of about 802 observations is needed.
-smpsize_lmm(eff.size = .3, k = 30)
+samplesize_mixed(eff.size = .3, k = 30)
 
 # Sample size for multilevel model with 20 cluster groups and a medium
 # to large effect size for linear models of 0.2. Five subjects per cluster and
 # hence a total sample size of about 107 observations is needed.
-smpsize_lmm(eff.size = .2, df.n = 5, k = 20, power = .9)
+samplesize_mixed(eff.size = .2, df.n = 5, k = 20, power = .9)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 data(nhanes_sample)
